@@ -21,19 +21,20 @@ import java.util.TreeMap;
  * delegate the specific parts to the subclasses. */
 public abstract class NetworkStatusImpl extends DescriptorImpl {
 
+  private static final long serialVersionUID = -2208207369822099643L;
+
   protected Map<String, Integer> flagIndexes = new HashMap<>();
 
   protected Map<Integer, String> flagStrings = new HashMap<>();
 
   protected NetworkStatusImpl(byte[] rawDescriptorBytes, int[] offsetAndLength,
-      File descriptorFile, boolean containsDirSourceEntries,
-      boolean blankLinesAllowed) throws DescriptorParseException {
+      File descriptorFile, boolean blankLinesAllowed)
+      throws DescriptorParseException {
     super(rawDescriptorBytes, offsetAndLength, descriptorFile,
         blankLinesAllowed);
-    this.splitAndParseParts(containsDirSourceEntries);
   }
 
-  private void splitAndParseParts(boolean containsDirSourceEntries)
+  protected final void splitAndParseParts(boolean containsDirSourceEntries)
       throws DescriptorParseException {
     int firstRIndex = this.findFirstIndexOfKey(Key.R);
     int firstDirectorySignatureIndex = this.findFirstIndexOfKey(
